@@ -19,14 +19,23 @@ class UnavailableObjectError(Exception):
 class UnavailableObject:
     """
     An unavailable object.
+
+    Args:
+        name (str): Name of the unavailable object.
+        msg (str, optional): Error message.
+        none_child (bool): Return None instead of throwing an exception
+            for __getattr and __getitem__.
     """
 
-    def __init__(self, name, msg=None):
+    def __init__(self, name, msg=None, none_child=False):
         self.name = name
         self.msg = msg
+        self.none_child = none_child
         self._orig_exc = sys.exc_info()[1]
 
     def raise_(self, *_, **__):
+        __tracebackhide__ = True
+
         msg = f"{self.name} is unavailable."
         if self.msg is not None:
             msg = f"{msg}\n\n{self.msg}"
@@ -34,8 +43,17 @@ class UnavailableObject:
         raise UnavailableObjectError(msg) from self._orig_exc
 
     __call__ = raise_
-    __getattr__ = raise_
-    __getitem__ = raise_
+
+    def __getattr__(self, name):
+        if self.none_child:
+            return None
+        self.raise_()
+
+    def __getitem__(self, name):
+        if self.none_child:
+            return None
+
+        self.raise_()
 
 
 def check_available(*objects):
@@ -44,6 +62,8 @@ def check_available(*objects):
 
     This is optional but can be used to have somthing fail early.
     """
+    __tracebackhide__ = True
+
     for obj in objects:
         if isinstance(obj, UnavailableObject):
             obj.raise_()
